Introduction
============

**Djecrety** is an implementation of the Django package from a `Web tool <https://djecrety.ir/>`_ with the same name.
This package provides a command to generate a new secret key for your project and save it to ``settings.py`` file.

You can use `Djecrety <https://djecrety.ir/>`_ web tool or simply install this package for automated testing and deployment.

Developed by `Majid Rouhi <https://www.thiswayyoufools.com/>`_ with passion & patience.
